@@ -17,6 +17,7 @@
 
 #include <gtest/gtest.h>
 #include <boost/version.hpp>
+#include <ignition/math/Angle.hh>
 #include "sdf/Param.hh"
 
 bool check_double(std::string num)
@@ -142,26 +143,21 @@ TEST(Param, HexUInt)
 /// Test setting and reading hex and non-hex float values.
 TEST(Param, HexFloat)
 {
+// Microsoft does not parse hex values properly.
+// https://bitbucket.org/osrf/sdformat/issues/114
+#ifndef _MSC_VER
   sdf::Param floatParam("key", "float", "0", false, "description");
   float value;
   EXPECT_TRUE(floatParam.Get<float>(value));
   EXPECT_FLOAT_EQ(value, 0.0f);
 
-  // Boost 1.58 and higher parses hex integers into floating point variables
-  // successfully, while older versions don't
-#if (BOOST_VERSION >= 105800)
-  {
-    EXPECT_TRUE(floatParam.SetFromString("0x01"));
-    EXPECT_TRUE(floatParam.Get<float>(value));
-    EXPECT_FLOAT_EQ(value, 1.0f);
-  }
-#else
-  {
-    EXPECT_FALSE(floatParam.SetFromString("0x01"));
-    EXPECT_TRUE(floatParam.Get<float>(value));
-    EXPECT_FLOAT_EQ(value, 0.0f);
-  }
-#endif
+  EXPECT_TRUE(floatParam.SetFromString("0x01"));
+  EXPECT_TRUE(floatParam.Get<float>(value));
+  EXPECT_FLOAT_EQ(value, 1.0f);
+
+  EXPECT_TRUE(floatParam.SetFromString("0X2A"));
+  EXPECT_TRUE(floatParam.Get<float>(value));
+  EXPECT_FLOAT_EQ(value, 42.0f);
 
   EXPECT_TRUE(floatParam.SetFromString("0.123"));
   EXPECT_TRUE(floatParam.Get<float>(value));
@@ -170,6 +166,7 @@ TEST(Param, HexFloat)
   EXPECT_FALSE(floatParam.SetFromString("1.0e100"));
   EXPECT_TRUE(floatParam.Get<float>(value));
   EXPECT_FLOAT_EQ(value, 0.123f);
+#endif
 }
 
 ////////////////////////////////////////////////////
@@ -181,29 +178,24 @@ TEST(Param, HexDouble)
   EXPECT_TRUE(doubleParam.Get<double>(value));
   EXPECT_DOUBLE_EQ(value, 0.0);
 
-  // Boost 1.58 and higher parses hex integers into floating point variables
-  // successfully, while older versions don't
-#if (BOOST_VERSION >= 105800)
-  {
-    EXPECT_TRUE(doubleParam.SetFromString("0x01"));
-    EXPECT_TRUE(doubleParam.Get<double>(value));
-    EXPECT_DOUBLE_EQ(value, 1.0);
-  }
-#else
-  {
-    EXPECT_FALSE(doubleParam.SetFromString("0x01"));
-    EXPECT_TRUE(doubleParam.Get<double>(value));
-    EXPECT_DOUBLE_EQ(value, 0.0);
-  }
-#endif
-
-  EXPECT_TRUE(doubleParam.SetFromString("0.123"));
+// Microsoft does not parse hex values properly.
+// https://bitbucket.org/osrf/sdformat/issues/114
+#ifndef _MSC_VER
+  EXPECT_TRUE(doubleParam.SetFromString("0x01"));
   EXPECT_TRUE(doubleParam.Get<double>(value));
-  EXPECT_DOUBLE_EQ(value, 0.123);
+  EXPECT_DOUBLE_EQ(value, 1.0);
+
+  EXPECT_TRUE(doubleParam.SetFromString("0X2A"));
+  EXPECT_TRUE(doubleParam.Get<double>(value));
+  EXPECT_DOUBLE_EQ(value, 42.0);
+#endif
+  EXPECT_TRUE(doubleParam.SetFromString("0.123456789"));
+  EXPECT_TRUE(doubleParam.Get<double>(value));
+  EXPECT_DOUBLE_EQ(value, 0.123456789);
 
   EXPECT_FALSE(doubleParam.SetFromString("1.0e1000"));
   EXPECT_TRUE(doubleParam.Get<double>(value));
-  EXPECT_DOUBLE_EQ(value, 0.123);
+  EXPECT_DOUBLE_EQ(value, 0.123456789);
 }
 
 ////////////////////////////////////////////////////
@@ -221,6 +213,16 @@ TEST(Param, uint64t)
   EXPECT_EQ(value, UINT64_MAX);
 }
 
+////////////////////////////////////////////////////
+/// Unknown type, should fall back to lexical_cast
+TEST(Param, UnknownType)
+{
+  sdf::Param doubleParam("key", "double", "1.0", false, "description");
+  ignition::math::Angle value;
+  EXPECT_TRUE(doubleParam.Get<ignition::math::Angle>(value));
+  EXPECT_DOUBLE_EQ(value.Radian(), 1.0);
+}
+
 /////////////////////////////////////////////////
 /// Main
 int main(int argc, char **argv)
