@@ -17,7 +17,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <map>
-
+#include <boost/algorithm/string.hpp>
 #include <boost/filesystem.hpp>
 
 #include "sdf/Console.hh"
@@ -262,6 +262,12 @@ bool initXml(TiXmlElement *_xml, ElementPtr _sdf)
     ElementPtr element(new Element);
 
     initFile(filename, element);
+
+    // override description for include elements
+    TiXmlElement *description = child->FirstChildElement("description");
+    if (description)
+      element->SetDescription(description->GetText());
+
     _sdf->AddElementDescription(element);
   }
 
@@ -691,11 +697,17 @@ bool readXml(TiXmlElement *_xml, ElementPtr _sdf)
                 elemXml->FirstChildElement("name")->GetText());
         }
 
-        if (elemXml->FirstChildElement("pose"))
+        TiXmlElement *poseElemXml = elemXml->FirstChildElement("pose");
+        if (poseElemXml)
         {
-          includeSDF->Root()->GetElement("model")->GetElement(
-              "pose")->GetValue()->SetFromString(
-                elemXml->FirstChildElement("pose")->GetText());
+          sdf::ElementPtr poseElem =
+              includeSDF->Root()->GetElement("model")->GetElement("pose");
+
+          poseElem->GetValue()->SetFromString(poseElemXml->GetText());
+
+          const char *frame = poseElemXml->Attribute("frame");
+          if (frame)
+            poseElem->GetAttribute("frame")->SetFromString(frame);
         }
 
         if (elemXml->FirstChildElement("static"))
@@ -930,4 +942,60 @@ void addNestedModel(ElementPtr _sdf, ElementPtr _includeSDF)
     elem = nextElem;
   }
 }
+
+/////////////////////////////////////////////////
+bool convertFile(const std::string &_filename, const std::string &_version,
+    SDFPtr _sdf)
+{
+  std::string filename = sdf::findFile(_filename);
+
+  if (filename.empty())
+  {
+    sdferr << "Error finding file [" << _filename << "].\n";
+    return false;
+  }
+
+  TiXmlDocument xmlDoc;
+  if (xmlDoc.LoadFile(filename))
+  {
+    if (sdf::Converter::Convert(&xmlDoc, _version, true))
+    {
+      return sdf::readDoc(&xmlDoc, _sdf, filename);
+    }
+  }
+  else
+  {
+    sdferr << "Error parsing file[" << filename << "]\n";
+  }
+
+  return false;
+}
+
+/////////////////////////////////////////////////
+bool convertString(const std::string &_sdfString, const std::string &_version,
+    SDFPtr _sdf)
+{
+  if (_sdfString.empty())
+  {
+    sdferr << "SDF string is empty.\n";
+    return false;
+  }
+
+  TiXmlDocument xmlDoc;
+  xmlDoc.Parse(_sdfString.c_str());
+
+  if (!xmlDoc.Error())
+  {
+    if (sdf::Converter::Convert(&xmlDoc, _version, true))
+    {
+      return sdf::readDoc(&xmlDoc, _sdf, "data-string");
+    }
+  }
+  else
+  {
+    sdferr << "Error parsing XML from string[" << _sdfString << "]\n";
+  }
+
+  return false;
+}
 }
