@@ -16,7 +16,6 @@
 */
 
 #include <gtest/gtest.h>
-#include <boost/filesystem.hpp>
 #include <map>
 #include "sdf/sdf.hh"
 
@@ -50,11 +49,6 @@ bool findJointInModel(std::string desired_joint_name, sdf::SDFPtr robot)
 /////////////////////////////////////////////////
 TEST(SDFParser, DisableFixedJointReductionTest)
 {
-  char *pathCStr = getenv("SDF_PATH");
-  boost::filesystem::path path = PROJECT_SOURCE_PATH;
-  path = path / "sdf" / SDF_VERSION;
-  setenv("SDF_PATH", path.string().c_str(), 1);
-
   sdf::SDFPtr robot(new sdf::SDF());
   sdf::init(robot);
   ASSERT_TRUE(sdf::readFile(SDF_FIXED_JNT, robot));
@@ -63,15 +57,6 @@ TEST(SDFParser, DisableFixedJointReductionTest)
   sdf::init(robot_disable_lumping);
   ASSERT_TRUE(sdf::readFile(SDF_FIXED_JNT_NO_LUMPING, robot_disable_lumping));
 
-  if (pathCStr)
-  {
-    setenv("SDF_PATH", pathCStr, 1);
-  }
-  else
-  {
-    unsetenv("SDF_PATH");
-  }
-
   ASSERT_FALSE(findJointInModel("joint12a", robot));
   ASSERT_FALSE(findJointInModel("joint23a", robot));
 
